@@ -1,3 +1,4 @@
+import inspect
 from copy import deepcopy
 from typing import List, Callable, Tuple, Union, Any, TypeVar
 
@@ -21,11 +22,11 @@ class FeaturesAndLabels(object):
     """
 
     def __init__(self,
-                 features: Typing.MlGetItem,
-                 labels: Typing.MlGetItem,
-                 sample_weights: Typing.MlGetItem = None,
-                 gross_loss: Typing.MlGetItem = None,
-                 targets: Typing.MlGetItem = None,
+                 features: Typing._Selector,
+                 labels: Typing._Selector,
+                 sample_weights: Typing._Selector = None,
+                 gross_loss: Typing._Selector = None,
+                 targets: Typing._Selector = None,
                  label_type = None,
                  **kwargs):
         """
@@ -67,6 +68,17 @@ class FeaturesAndLabels(object):
         self._min_required_samples = None
         self._label_columns = None
 
+    def set_min_required_samples(self, min_required: int):
+        self._min_required_samples = min_required
+
+        return self
+
+    def set_label_columns(self, column_names, over_write=False) -> 'FeaturesAndLabels':
+        if not self._label_columns or over_write:
+            self._label_columns = column_names
+
+        return self
+
     @property
     def features(self):
         return self._features
@@ -137,5 +149,19 @@ class FeaturesAndLabels(object):
         return self.__id__() == other.__id__() if isinstance(other, FeaturesAndLabels) else False
 
     def __repr__(self):
-        return f'FeaturesAndLabels({self.features}, {self.labels}, {self.sample_weights}, {self.targets})'
+        def source(params):
+            if params is None:
+                return None
+            else:
+                return [inspect.getsource(p) if callable(p) else p if isinstance(p, (bool, int, float, str)) else repr(p) for p in params]
+
+        return f'FeaturesAndLabels(' \
+               f'\t{source(self.features)}, ' \
+               f'\t{source(self.labels)}, ' \
+               f'\t{source(self.sample_weights)}, ' \
+               f'\t{source(self.gross_loss)}, ' \
+               f'\t{source(self.targets)}, ' \
+               f'\t{self.label_type}, ' \
+               f'\t{self.kwargs}' \
+               f')'
 
